TcpSocket

Struct TcpSocket 

pub struct TcpSocket { /* private fields */ }
Available on crate feature net only.
A TCP socket that has not yet been converted to a TcpStream or TcpListener.

Implementations

Source

impl TcpSocket

pub async fn new_v4() -> Result<TcpSocket, Error>

Creates a new socket configured for IPv4.

pub async fn new_v6() -> Result<TcpSocket, Error>

Creates a new socket configured for IPv6.

pub fn set_keepalive(&self, keepalive: bool) -> Result<(), Error>

Sets value for the SO_KEEPALIVE option on this socket.

pub fn keepalive(&self) -> Result<bool, Error>

Gets the value of the SO_KEEPALIVE option on this socket.

pub fn set_reuseaddr(&self, reuseaddr: bool) -> Result<(), Error>

Allows the socket to bind to an in-use address.

pub fn reuseaddr(&self) -> Result<bool, Error>

Retrieves the value set for SO_REUSEADDR on this socket.

pub fn set_reuseport(&self, reuseport: bool) -> Result<(), Error>

Available on Unix and non-Solaris and non-illumos and non-Cygwin only.

Allows the socket to bind to an in-use port. Only available for supported unix systems.

pub fn reuseport(&self) -> Result<bool, Error>

Available on Unix and non-Solaris and non-illumos and non-Cygwin only.

Allows the socket to bind to an in-use port. Only available for supported unix systems.

pub fn set_send_buffer_size(&self, size: u32) -> Result<(), Error>

Sets the size of the TCP send buffer on this socket.

On most operating systems, this sets the SO_SNDBUF socket option.

pub fn send_buffer_size(&self) -> Result<u32, Error>

Returns the size of the TCP send buffer for this socket.

On most operating systems, this is the value of the SO_SNDBUF socket option.

pub fn set_recv_buffer_size(&self, size: u32) -> Result<(), Error>

Sets the size of the TCP receive buffer on this socket.

On most operating systems, this sets the SO_RCVBUF socket option.

pub fn recv_buffer_size(&self) -> Result<u32, Error>

Returns the size of the TCP receive buffer for this socket.

On most operating systems, this is the value of the SO_RCVBUF socket option.

pub fn set_zero_linger(&self) -> Result<(), Error>

Sets a linger duration of zero on this socket by setting the SO_LINGER option.

pub fn linger(&self) -> Result<Option<Duration>, Error>

Reads the linger duration for this socket by getting the SO_LINGER option.

pub fn set_nodelay(&self, nodelay: bool) -> Result<(), Error>

Sets the value of the TCP_NODELAY option on this socket.

If set, this option disables the Nagle algorithm. This means that segments are always sent as soon as possible, even if there is only a small amount of data. When not set, data is buffered until there is a sufficient amount to send out, thereby avoiding the frequent sending of small packets.

pub fn nodelay(&self) -> Result<bool, Error>

Gets the value of the TCP_NODELAY option on this socket.

For more information about this option, see set_nodelay.

pub fn tclass_v6(&self) -> Result<u32, Error>

Available on Android or DragonFly BSD or FreeBSD or Fuchsia or Linux or macOS or NetBSD or OpenBSD or Cygwin only.

Gets the value of the IPV6_TCLASS option for this socket.

For more information about this option, see set_tclass_v6.

pub fn set_tclass_v6(&self, tclass: u32) -> Result<(), Error>

Available on Android or DragonFly BSD or FreeBSD or Fuchsia or Linux or macOS or NetBSD or OpenBSD or Cygwin only.

Sets the value for the IPV6_TCLASS option on this socket.

Specifies the traffic class field that is used in every packet sent from this socket.

Note

This may not have any effect on IPv4 sockets.

pub fn tos_v4(&self) -> Result<u32, Error>

Available on neither Fuchsia nor Redox OS nor Solaris nor illumos nor Haiku.

Gets the value of the IP_TOS option for this socket.

For more information about this option, see set_tos_v4.

pub fn set_tos_v4(&self, tos: u32) -> Result<(), Error>

Available on neither Fuchsia nor Redox OS nor Solaris nor illumos nor Haiku.

Sets the value for the IP_TOS option on this socket.

This value sets the type-of-service field that is used in every packet sent from this socket.

Note
pub fn device(&self) -> Result<Option<Vec<u8>>, Error>

Available on Android or Fuchsia or Linux only.

Gets the value for the SO_BINDTODEVICE option on this socket

Returns the interface name of the device to which this socket is bound.

pub fn bind_device(&self, interface: Option<&[u8]>) -> Result<(), Error>

Available on Android or Fuchsia or Linux only.

Sets the value for the SO_BINDTODEVICE option on this socket

If a socket is bound to an interface, only packets received from that particular interface are processed by the socket. Note that this only works for some socket types, particularly AF_INET sockets.

If interface is None or an empty string it removes the binding.

pub fn local_addr(&self) -> Result<SocketAddr, Error>

Gets the local address of this socket.

pub fn take_error(&self) -> Result<Option<Error>, Error>

Returns the value of the SO_ERROR option.

pub async fn bind(&self, addr: SocketAddr) -> Result<(), Error>

Binds the socket to the given address.

pub async fn connect(self, addr: SocketAddr) -> Result<TcpStream, Error>

Establishes a TCP connection with a peer at the specified socket address.

The TcpSocket is consumed. Once the connection is established, a connected TcpStream is returned. If the connection fails, the encountered error is returned.

On Windows, the socket should be bound to an address before connecting.

pub async fn listen(self, backlog: i32) -> Result<TcpListener, Error>

Converts the socket into a TcpListener.

backlog defines the maximum number of pending connections that are queued by the operating system at any given time. Connections are removed from the queue with TcpListener::accept. When the queue is full, the operating system will start rejecting connections.

pub fn from_std_stream(stream: TcpStream) -> Result<TcpSocket, Error>

Converts a std::net::TcpStream into a TcpSocket. The provided socket must not have been connected prior to calling this function. This function is typically used together with crates such as [socket2] to configure socket options that are not available on TcpSocket.