UnixListener

Struct UnixListener 

pub struct UnixListener { /* private fields */ }
Available on crate feature net only.
A Unix socket server, listening for connections.

You can accept a new connection by using the UnixListener::accept method.

Examples

use compio_io::{AsyncReadExt, AsyncWriteExt};
use compio_net::{UnixListener, UnixStream};
use tempfile::tempdir;

let dir = tempdir().unwrap();
let sock_file = dir.path().join("unix-server.sock");

let listener = UnixListener::bind(&sock_file).await.unwrap();

let (mut tx, (mut rx, _)) =
    futures_util::try_join!(UnixStream::connect(&sock_file), listener.accept()).unwrap();

tx.write_all("test").await.0.unwrap();

let (_, buf) = rx.read_exact(Vec::with_capacity(4)).await.unwrap();

assert_eq!(buf, b"test");

Implementations

Source

impl UnixListener

pub async fn bind(path: impl AsRef<Path>) -> Result<UnixListener, Error>

Creates a new UnixListener, which will be bound to the specified file path. See UnixListener::bind_addr for more details.

pub async fn bind_addr(addr: &SockAddr) -> Result<UnixListener, Error>

Creates a new UnixListener with [SockAddr], which will be bound to the specified file path. The file path cannot yet exist.

To configure the socket before binding, you can use the UnixSocket type.

pub fn from_std(stream: UnixListener) -> Result<UnixListener, Error>

Available on Unix only.

Creates new UnixListener from a std::os::unix::net::UnixListener.

pub fn close(self) -> impl Future<Output = Result<(), Error>>

Close the socket. If the returned future is dropped before polling, the socket won’t be closed.

See TcpStream::close for more details.

pub async fn accept(&self) -> Result<(UnixStream, SockAddr), Error>

Accepts a new incoming connection from this listener.

This function will yield once a new Unix domain socket connection is established. When established, the corresponding UnixStream and the remote peer’s address will be returned.

pub fn incoming(&self) -> UnixIncoming<'_>

Returns a stream of incoming connections to this listener.

pub fn local_addr(&self) -> Result<SockAddr, Error>

Returns the local address that this listener is bound to.

pub fn take_error(&self) -> Result<Option<Error>, Error>

Returns the value of the SO_ERROR option.