UnixStream

Struct UnixStream 

pub struct UnixStream { /* private fields */ }
Available on crate feature net only.
A Unix stream between two local sockets on Windows & WSL.

A Unix stream can either be created by connecting to an endpoint, via the connect method, or by accepting a connection from a listener.

Examples

use compio_io::AsyncWrite;
use compio_net::UnixStream;

// Connect to a peer
let mut stream = UnixStream::connect("unix-server.sock").await.unwrap();

// Write some data.
stream.write("hello world!").await.unwrap();

Implementations

Source

impl UnixStream

pub async fn connect(path: impl AsRef<Path>) -> Result<UnixStream, Error>

Opens a Unix connection to the specified file path. See UnixStream::connect_addr for more details.

pub async fn connect_addr(addr: &SockAddr) -> Result<UnixStream, Error>

Opens a Unix connection to the specified address. There must be a UnixListener or equivalent listening on the corresponding Unix domain socket to successfully connect and return a UnixStream.

To configure the socket before connecting, you can use the UnixSocket type.

pub fn from_std(stream: UnixStream) -> Result<UnixStream, Error>

Available on Unix only.

Creates new UnixStream from a std::os::unix::net::UnixStream.

pub fn close(self) -> impl Future<Output = Result<(), Error>>

Close the socket. If the returned future is dropped before polling, the socket won’t be closed.

See TcpStream::close for more details.

pub fn peer_addr(&self) -> Result<SockAddr, Error>

Returns the socket path of the remote peer of this connection.

pub fn local_addr(&self) -> Result<SockAddr, Error>

Returns the socket path of the local half of this connection.

pub fn take_error(&self) -> Result<Option<Error>, Error>

Returns the value of the SO_ERROR option.

pub fn split(&self) -> (ReadHalf<'_, UnixStream>, WriteHalf<'_, UnixStream>)

Splits a UnixStream into a read half and a write half, which can be used to read and write the stream concurrently.

This method is more efficient than into_split, but the halves cannot be moved into independently spawned tasks.

pub fn into_split(self) -> (UnixStream, UnixStream)

Splits a UnixStream into a read half and a write half, which can be used to read and write the stream concurrently.

Unlike split, the owned halves can be moved to separate tasks.

pub fn to_poll_fd(&self) -> Result<PollFd<Socket>, Error>

Create PollFd from inner socket.

pub fn into_poll_fd(self) -> Result<PollFd<Socket>, Error>

Create PollFd from inner socket.